#include <iostream>

#include <sdsl/int_vector.hpp>
#include <sdsl/sd_vector.hpp>

using namespace std;
using namespace sdsl;

int main()
{
    bit_vector b = bit_vector(80 * (1 << 20), 0);
    for (size_t i = 0; i < b.size(); i += 100)
        b[i] = 1;
    sd_vector<> sdb(b);
    write_structure<JSON_FORMAT>(sdb, cout);
}
